..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Objectives
----------

The goals for this chapter are as follows:

-  To understand that complex problems that may otherwise be difficult
   to solve may have a simple recursive solution.

-  To learn how to formulate programs recursively.

-  To understand and apply the three laws of recursion.

-  To understand recursion as a form of iteration.

-  To implement the recursive formulation of a problem.

-  To understand how recursion is implemented by a computer system.


.. index:: mutable, immutable, tuple
.. index:: fractal, fractal; Koch, Koch fractal
